@@ -95,6 +95,8 @@ def GC_skew(seq, window=100):
     Returns a list of ratios (floats), controlled by the length of the sequence
     and the size of the window.
 
+    Returns 0 for windows without any G/C by handling zero division errors.
+
     Does NOT look at any ambiguous nucleotides.
     """
     # 8/19/03: Iddo: added lowercase
@@ -103,7 +105,10 @@ def GC_skew(seq, window=100):
         s = seq[i: i + window]
         g = s.count('G') + s.count('g')
         c = s.count('C') + s.count('c')
-        skew = (g - c) / float(g + c)
+        try:
+            skew = (g - c) / float(g + c)
+        except ZeroDivisionError:
+            skew = 0.0
         values.append(skew)
     return values
 
@@ -328,13 +333,14 @@ def molecular_weight(seq, seq_type=None, double_stranded=False, circular=False,
     Only unambiguous letters are allowed. Nucleotide sequences are assumed to
     have a 5' phosphate.
 
-        - seq: String or Biopython sequence object.
-        - seq_type: The default (None) is to take the alphabet from the seq argument,
-          or assume DNA if the seq argument is a string. Override this with
-          a string 'DNA', 'RNA', or 'protein'.
-        - double_stranded: Calculate the mass for the double stranded molecule?
-        - circular: Is the molecule circular (has no ends)?
-        - monoisotopic: Use the monoisotopic mass tables?
+    Arguments:
+     - seq: String or Biopython sequence object.
+     - seq_type: The default (None) is to take the alphabet from the seq argument,
+       or assume DNA if the seq argument is a string. Override this with
+       a string 'DNA', 'RNA', or 'protein'.
+     - double_stranded: Calculate the mass for the double stranded molecule?
+     - circular: Is the molecule circular (has no ends)?
+     - monoisotopic: Use the monoisotopic mass tables?
 
     Note that for backwards compatibility, if the seq argument is a string,
     or Seq object with a generic alphabet, and no seq_type is specified
@@ -440,8 +446,6 @@ def molecular_weight(seq, seq_type=None, double_stranded=False, circular=False,
     except KeyError as e:
         raise ValueError('%s is not a valid unambiguous letter for %s'
                          % (e, seq_type))
-    except:
-        raise
 
     if seq_type in ('DNA', 'RNA') and double_stranded:
         seq = str(Seq(seq).complement())
